==> hippo4j-spring-boot-starter-1.4.0-alpha-sources.jar: cn/hippo4j/springboot/starter/remote/HttpScheduledHealthCheck.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cn.hippo4j.springboot.starter.remote;

import cn.hippo4j.common.web.base.Result;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;

import java.util.Objects;

import static cn.hippo4j.common.constant.Constants.HEALTH_CHECK_PATH;
import static cn.hippo4j.common.constant.Constants.UP;

/**
 * Server health check.
 */
@Slf4j
@AllArgsConstructor
public class HttpScheduledHealthCheck extends AbstractHealthCheck {

    private final HttpAgent httpAgent;

    @Override
    protected boolean sendHealthCheck() {
        boolean healthStatus = false;
        try {
            Result healthResult = httpAgent.httpGetSimple(HEALTH_CHECK_PATH);
            if (healthResult != null && Objects.equals(healthResult.getData(), UP)) {
                healthStatus = true;
            }
        } catch (Throwable ex) {
            log.error("Failed to periodically check the health status of the server.", ex.getMessage());
        }
        return healthStatus;
    }
}

==> hippo4j-spring-boot-starter-1.4.2-alpha-sources.jar: cn/hippo4j/springboot/starter/remote/HttpScheduledHealthCheck.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cn.hippo4j.springboot.starter.remote;

import cn.hippo4j.common.web.base.Result;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;

import java.util.Objects;

import static cn.hippo4j.common.constant.Constants.HEALTH_CHECK_PATH;
import static cn.hippo4j.common.constant.Constants.UP;

/**
 * Server health check.
 */
@Slf4j
@AllArgsConstructor
public class HttpScheduledHealthCheck extends AbstractHealthCheck {

    private final HttpAgent httpAgent;

    @Override
    protected boolean sendHealthCheck() {
        boolean healthStatus = false;
        try {
            Result healthResult = httpAgent.httpGetSimple(HEALTH_CHECK_PATH);
            if (healthResult != null && Objects.equals(healthResult.getData(), UP)) {
                healthStatus = true;
            }
        } catch (Throwable ex) {
            log.error("Failed to periodically check the health status of the server. message: {}", ex.getMessage());
        }
        return healthStatus;
    }
}
